tdub.ml_train
-------------

A module for handling training

.. currentmodule:: tdub.ml_train

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   ResponseHistograms
   SingleTrainingSummary

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   prepare_from_root
   folded_training
   lgbm_gen_classifier
   lgbm_train_classifier
   single_training
   sklearn_gen_classifier
   sklearn_train_classifier
   tdub_train_axes


Reference
^^^^^^^^^

.. autoclass:: ResponseHistograms
   :members:

.. autoclass:: SingleTrainingSummary
   :members:

.. autofunction:: prepare_from_root
.. autofunction:: folded_training
.. autofunction:: lgbm_gen_classifier
.. autofunction:: lgbm_train_classifier
.. autofunction:: single_training
.. autofunction:: sklearn_gen_classifier
.. autofunction:: sklearn_train_classifier
.. autofunction:: tdub_train_axes
